@@ -87,6 +87,15 @@ public:
         FormatHtml,
         FormatPlain
     };
+
+    /**
+     * Returns a pretty short representation of the base path of the url, considering the currently loaded projects:
+     * When the file is part of a currently loaded project, that projects name is shown as prefix instead of the
+     * the full file path.
+     * @param format formatting used for the string
+     */
+    Q_SCRIPTABLE virtual QString prettyFilePath(KUrl url, FormattingOptions format = FormatHtml) const = 0;
+    
     /**
      * Returns a pretty short representation of the given url, considering the currently loaded projects:
      * When the file is part of a currently loaded project, that projects name is shown as prefix instead of the
