@@ -103,9 +103,9 @@ ColorCache::ColorCache(QObject* parent)
     }
   }
 
-  m_self = this;
+  updateInternal();
 
-  update();
+  m_self = this;
 }
 
 ColorCache::~ColorCache()
@@ -232,17 +232,23 @@ void ColorCache::updateColorsFromSettings()
 
 void ColorCache::update()
 {
+  if ( !m_self ) {
+    // don't update on startup, updateInternal is called directly there
+    return;
+  }
+
   QMetaObject::invokeMethod(this, "updateInternal", Qt::QueuedConnection);
 }
 
 void ColorCache::updateInternal()
 {
-  if ( !m_self ) { // don't update during startup
+  generateColors();
+
+  if ( !m_self ) {
+    // don't do anything else fancy on startup
     return;
   }
 
-  generateColors();
-
   emit colorsGotChanged();
 
   // rehighlight open documents
