@@ -59,6 +59,17 @@ namespace KDevelop {
                 return m_dataSize;
             }
             
+            uint countFreeItems() {
+                EmbeddedTreeAlgorithms<Data, Handler> alg(m_data, m_dataSize, m_centralFreeItem);
+                return alg.countFreeItems();
+            }
+            
+            void verify() {
+                EmbeddedTreeAlgorithms<Data, Handler> alg(m_data, m_dataSize, m_centralFreeItem);
+                alg.verifyTreeConsistent();
+                alg.verifyOrder();
+            }
+            
             ///Returns the underlying array. That array may contain invalid/free items.
             const Data* data() const {
                 return m_data;
@@ -303,12 +314,14 @@ namespace KDevelop {
         int m_match;
     };
 
+    ///Filters a list-embedded set by a binary tree set as managed by the SetRepository data structures
     template<class Data, class Handler, class Data2, class TreeSet, class KeyExtractor>
     class ConvenientEmbeddedSetTreeFilterIterator : public ConvenientEmbeddedSetIterator<Data, Handler> {
         public:
         ConvenientEmbeddedSetTreeFilterIterator() : m_match(-1) {
         }
-        ConvenientEmbeddedSetTreeFilterIterator(const ConvenientEmbeddedSetIterator<Data, Handler>& base, const TreeSet& rhs) : ConvenientEmbeddedSetIterator<Data, Handler>(base), m_rhs(rhs), m_match(-1) {
+        ///@param noFiltering whether the given input is pre-filtered. If this is true, base will be iterated without skipping any items.
+        ConvenientEmbeddedSetTreeFilterIterator(const ConvenientEmbeddedSetIterator<Data, Handler>& base, const TreeSet& rhs, bool noFiltering = false) : ConvenientEmbeddedSetIterator<Data, Handler>(base), m_rhs(rhs), m_match(-1), m_noFiltering(noFiltering) {
             if(rhs.node().isValid()) {
                 //Correctly initialize the initial bounds
                 int ownStart = lowerBound(rhs.node().firstItem(), 0, this->m_dataSize);
@@ -347,6 +360,13 @@ namespace KDevelop {
 
         private:
         void go() {
+            if(m_noFiltering) {
+                ++m_match;
+                if((uint)m_match >= this->m_dataSize)
+                    m_match = -1;
+                return;
+            }
+
             if(m_match != -1) {
                 //Match multiple items in this list to one in the tree
                 m_match = this->firstValidItem(m_match+1, this->m_dataSize);
@@ -476,8 +496,174 @@ namespace KDevelop {
         TreeSet m_rhs;
         int m_match, m_matchBound;
         Data2 m_matchingTo;
+        bool m_noFiltering;
     };
 
+    ///Same as above, except that it visits all filtered items with a visitor, instead of iterating over them.
+    ///This is more efficient. The visiting is done directly from within the constructor.
+    template<class Data, class Handler, class Data2, class TreeSet, class KeyExtractor, class Visitor>
+    class ConvenientEmbeddedSetTreeFilterVisitor : public ConvenientEmbeddedSetIterator<Data, Handler> {
+        public:
+        ConvenientEmbeddedSetTreeFilterVisitor() {
+        }
+        
+        typedef QPair<QPair<uint, uint>, typename TreeSet::Node > Bounds;
+        
+        struct Bound {
+            inline Bound(uint s, uint e, const typename TreeSet::Node& n) : start(s), end(e), node(n) {
+            }
+            Bound() {
+            }
+            uint start;
+            uint end;
+            typename TreeSet::Node node;
+        };
+        
+        ///@param noFiltering whether the given input is pre-filtered. If this is true, base will be iterated without skipping any items.
+        ConvenientEmbeddedSetTreeFilterVisitor(Visitor& visitor, const ConvenientEmbeddedSetIterator<Data, Handler>& base, const TreeSet& rhs, bool noFiltering = false) : ConvenientEmbeddedSetIterator<Data, Handler>(base), m_visitor(visitor), m_rhs(rhs), m_noFiltering(noFiltering) {
+            
+            if(m_noFiltering) {
+                for(uint a = 0; a < this->m_dataSize; ++a)
+                    visitor(this->m_data[a]);
+                return;
+            }
+            
+            if(rhs.node().isValid())  {
+                //Correctly initialize the initial bounds
+                int ownStart = lowerBound(rhs.node().firstItem(), 0, this->m_dataSize);
+                if(ownStart == -1)
+                    return;
+                int ownEnd = lowerBound(rhs.node().lastItem(), ownStart, this->m_dataSize);
+                if(ownEnd == -1)
+                    ownEnd = this->m_dataSize;
+                else
+                    ownEnd += 1;
+                
+                go( Bound((uint)ownStart, (uint)ownEnd, rhs.node()) );
+            }
+        }
+        
+        private:
+        void go( Bound bound ) {
+
+            KDevVarLengthArray<Bound> bounds;
+            
+            while(true) {
+                if(bound.start >= bound.end)
+                    goto nextBound;
+                
+                if(bound.node.isFinalNode()) {
+                    //Check whether the item is contained
+                    int b = lowerBound(*bound.node, bound.start, bound.end);
+                    if(b != -1) {
+                        const Data2& matchTo(*bound.node);
+                    
+                        if(KeyExtractor::extract(this->m_data[b]) == matchTo) {
+                            while(1) {
+                                m_visitor(this->m_data[b]);
+                                b = this->firstValidItem(b+1, this->m_dataSize);
+                                if(b < (int)this->m_dataSize && b != -1 && KeyExtractor::extract(this->m_data[b]) == matchTo)
+                                    continue;
+                                else
+                                    break;
+                            }
+                        }
+                    }
+                    goto nextBound;
+                }else{
+                    //This is not a final node, split up the search into the sub-nodes
+                    typename TreeSet::Node leftNode = bound.node.leftChild();
+                    typename TreeSet::Node rightNode = bound.node.rightChild();
+                    Q_ASSERT(leftNode.isValid());
+                    Q_ASSERT(rightNode.isValid());
+                    
+                    
+                    Data2 leftLastItem = leftNode.lastItem();
+                    
+                    int rightSearchStart = lowerBound(rightNode.firstItem(), bound.start, bound.end);
+                    if(rightSearchStart == -1)
+                        rightSearchStart = bound.end;
+                    int leftSearchLast = lowerBound(leftLastItem, bound.start, rightSearchStart != -1 ? rightSearchStart : bound.end);
+                    if(leftSearchLast == -1)
+                        leftSearchLast = rightSearchStart-1;
+                    
+                    bool recurseLeft = false;
+                    if(leftSearchLast > (int)bound.start) {
+                        recurseLeft = true; //There must be something in the range bound.start -> leftSearchLast that matches the range
+                    }else if((int)bound.start == leftSearchLast) {
+                        //Check if the one item item under leftSearchStart is contained in the range
+                        Data2 leftFoundStartData = KeyExtractor::extract(this->m_data[bound.start]);
+                        recurseLeft = leftFoundStartData < leftLastItem || leftFoundStartData == leftLastItem;
+                    }
+                    
+                    bool recurseRight = false;
+                    if(rightSearchStart < (int)bound.end)
+                        recurseRight = true;
+                    
+                    if(recurseLeft && recurseRight)
+                        bounds.append( Bound(rightSearchStart, bound.end, rightNode) );
+                    
+                    if(recurseLeft) {
+                        bound.node = leftNode;
+                        if(leftSearchLast != -1)
+                            bound.end = leftSearchLast+1;
+                    }else if(recurseRight) {
+                        bound.node = rightNode;
+                        bound.start = rightSearchStart;
+                    }else{
+                        goto nextBound;
+                    }
+                    continue;
+                }
+                nextBound:
+                    if(bounds.isEmpty()) {
+                        return;
+                    }else{
+                        bound = bounds.back();
+                        bounds.pop_back();
+                    }
+            }
+        }
+        
+        ///Returns the first valid index that has an extracted data-value larger or equal to @param data.
+        ///Returns -1 if nothing is found.
+        int lowerBound(const Data2& data, int start, int end) {
+            int currentBound = -1;
+            while(1) {
+                if(start >= end)
+                    return currentBound;
+                
+                int center = (start + end)/2;
+                
+                //Skip free items, since they cannot be used for ordering
+                for(; center < end; ) {
+                    if(!Handler::isFree(this->m_data[center]))
+                        break;
+                    ++center;
+                }
+                
+                if(center == end) {
+                    end = (start + end)/2; //No non-free items found in second half, so continue search in the other
+                }else{
+                    Data2 centerData = KeyExtractor::extract(this->m_data[center]);
+                    //Even if the data equals we must continue searching to the left, since there may be multiple matching
+                    if(data == centerData || data < centerData) {
+                        currentBound = center;
+                        end = (start + end)/2;
+                    }else{
+                        //Continue search in second half
+                        start = center+1;
+                    }
+                }
+            }
+        }
+        
+        //Bounds that yet need to be matched. Always a range in the own vector, and a node that all items in the range are contained in
+        Visitor& m_visitor;
+        TreeSet m_rhs;
+        bool m_noFiltering;
+    };
+    
     template<class Data, class Handler>
     ConvenientEmbeddedSetIterator<Data, Handler> ConstantConvenientEmbeddedSet<Data, Handler>::iterator() const {
         return ConvenientEmbeddedSetIterator<Data, Handler>(m_data, m_dataSize, m_centralFreeItem);
