@@ -36,6 +36,8 @@
 
 #include "ui_vcscommitdialog.h"
 #include "vcsdiffpatchsources.h"
+#include <KComponentData>
+#include <vcspluginhelper.h>
 
 namespace KDevelop
 {
@@ -93,6 +95,7 @@ public:
     Ui::VcsCommitDialog ui;
     KDevelop::VcsDiff diff;
     QList< KUrl > m_selection;
+    QStringList m_oldMessages;
 };
 
 VcsCommitDialog::VcsCommitDialog( KDevelop::IPlugin *plugin, QWidget *parent )
@@ -100,6 +103,8 @@ VcsCommitDialog::VcsCommitDialog( KDevelop::IPlugin *plugin, QWidget *parent )
 {
     d->plugin = plugin;
 
+    d->m_oldMessages = retrieveOldCommitMessages();
+    
     d->ui.setupUi( mainWidget() );
     setButtons( KDialog::Ok | KDialog::Cancel );
     setWindowTitle( i18n("Commit Message") );
@@ -113,6 +118,7 @@ VcsCommitDialog::VcsCommitDialog( KDevelop::IPlugin *plugin, QWidget *parent )
 
 VcsCommitDialog::~VcsCommitDialog()
 {
+    addOldCommitMessage(d->ui.message->toPlainText());
     delete d;
 }
 
@@ -222,11 +228,12 @@ void VcsCommitDialog::setCommitCandidatesAndShow( const KUrl &url )
     job->exec();
     }
     
-    VCSCommitDiffPatchSource* patchSource = new VCSCommitDiffPatchSource(d->diff, d->urls, vcsiface);
+    VCSCommitDiffPatchSource* patchSource = new VCSCommitDiffPatchSource(d->diff, d->urls, vcsiface, d->m_oldMessages);
     
     if(showVcsDiff(patchSource))
     {
         connect(patchSource, SIGNAL(reviewFinished(QString,QList<KUrl>)), this, SLOT(reviewFinished(QString,QList<KUrl>)));
+        connect(patchSource, SIGNAL(reviewCancelled(QString)), this, SLOT(reviewCancalled(QString)));
         connect(patchSource, SIGNAL(destroyed(QObject*)), SLOT(deleteLater()));
     }else{
         delete patchSource;
@@ -234,6 +241,11 @@ void VcsCommitDialog::setCommitCandidatesAndShow( const KUrl &url )
     }
 }
 
+void VcsCommitDialog::reviewCancalled(QString message)
+{
+    d->ui.message->setPlainText(message);
+}
+
 void VcsCommitDialog::reviewFinished(QString message, QList< KUrl > selection)
 {
     d->ui.message->setPlainText(message);
