@@ -27,13 +27,13 @@
 #include <interfaces/iruncontroller.h>
 #include "vcsjob.h"
 #include <interfaces/iplugincontroller.h>
+#include <KComboBox>
 
 using namespace KDevelop;
 
-VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(const KDevelop::VcsDiff& vcsdiff, QMap< KUrl, KDevelop::VcsStatusInfo::State> selectable, IBasicVersionControl* vcs)
+VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(const KDevelop::VcsDiff& vcsdiff, QMap< KUrl, KDevelop::VcsStatusInfo::State> selectable, IBasicVersionControl* vcs, QStringList oldMessages)
     : VCSDiffPatchSource(vcsdiff), m_selectable(selectable), m_vcs(vcs)
 {
-    
     Q_ASSERT(m_vcs);
 
     m_commitMessageWidget = new QWidget;
@@ -42,10 +42,33 @@ VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(const KDevelop::VcsDiff& vcsd
     m_commitMessageEdit = new QTextEdit;
     m_commitMessageEdit->setFont( KGlobalSettings::fixedFont() );
     
-    layout->addWidget(new QLabel(i18n("Commit Message:")));
+    QHBoxLayout* titleLayout = new QHBoxLayout;
+    titleLayout->addWidget(new QLabel(i18n("Commit Message:")));
+    
+    m_oldMessages = new KComboBox;
+    
+    m_oldMessages->addItem(i18n("Old Messages"));
+    foreach(QString message, oldMessages)
+        m_oldMessages->addItem(message, message);
+    m_oldMessages->setMaximumWidth(200);
+    
+    connect(m_oldMessages, SIGNAL(currentIndexChanged(QString)), this, SLOT(oldMessageChanged(QString)));
+    
+    titleLayout->addWidget(m_oldMessages);
+    
+    layout->addLayout(titleLayout);
     layout->addWidget(m_commitMessageEdit);
 }
 
+void VCSCommitDiffPatchSource::oldMessageChanged(QString text)
+{
+    if(m_oldMessages->currentIndex() != 0)
+    {
+        m_oldMessages->setCurrentIndex(0);
+        m_commitMessageEdit->setText(text);
+    }
+}
+
 VCSDiffPatchSource::VCSDiffPatchSource(const KDevelop::VcsDiff& vcsdiff)
 {
     KTemporaryFile temp2;
@@ -109,6 +132,14 @@ bool VCSCommitDiffPatchSource::canCancel() const {
 }
 
 void VCSCommitDiffPatchSource::cancelReview() {
+    
+    QString message;
+
+    if (m_commitMessageEdit)
+        message = m_commitMessageEdit->toPlainText();
+
+    emit reviewCancelled(message);
+    
     deleteLater();
 }
 
